/*
-------------------------------------------------------------------------------
    This file is a part of the VST Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: maindialog.h
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: MainDialog class header
-------------------------------------------------------------------------------
*/

#ifndef MAINDIALOG_H
#define MAINDIALOG_H

#include <QMainWindow>

#include "fxheader.h"
#include "vstlistmodel.h"
#include "vpgvsthost.h"
#include "parametertablemodel.h"
#include "paramvaluedelegate.h"
#include "randommodedelegate.h"
#include "vpgsettings.h"

class QPushButton;
class QLabel;
class QListView;
class QPixmap;
class QProgressBar;
class QTableView;


//-----------------------------------------------------------------------------
class MainDialog : public QMainWindow
{
    Q_OBJECT

public:
    MainDialog(VpgSettings& settings);
    ~MainDialog();
    void closeEvent(QCloseEvent* event);

signals:
    void validHeader(FxHeaderStruct* data);

private slots:
    void generatePreset();
    void showLabelHeader(FxHeaderStruct* data);
    void updateParamList(bool isHeaderValid);
    void openVstList();
    void saveVstList();
    void newVstList();
    void showCopyright();

    void importParamFromVstOrPreset(); 	//selection
    void loadParamFromVst(QString fileName); 			//from dll file
    void openPreset(QString fileName);					//from fxp or fxb file

    void setGlobalRandomMethod(Parameter::RandomMode method);
    void setGlobalRandomMethodUniform();
    void setGlobalRandomMethodNormal();
    void setGlobalRandomMethodConstant();
    void setGlobalRandomMethodTotal();

    void onVstListDoubleClicked(const QModelIndex& index);

private:
    void dragEnterEvent(QDragEnterEvent *event);    //from Qt
    void dropEvent(QDropEvent *event);               //from Qt

    bool loadVst(QString fileName);

    //Buttons
    QPushButton *btnGen;

    //Toolbars
    QToolBar *vstImportToolBar;
    QToolBar *vstListToolBar;
    QToolBar *randomMethodToolBar;

    //Labels
    QLabel *headerDescription;

    //list
    QListView *vstList;

    //Image
    QPixmap const *vpgLogo;

    //Progress Bar
    QProgressBar *progressBar;

    //Our class to manage header parameters
    FxHeader *fxHeader;

    //Our object to read and save xml files
    VSTListModel *vstListModel;

    //VST host
    VpgVstHost *vpgVstHost;

    //Table to display parameters values
    QTableView *parameterTable;
    ParameterTableModel *parameterTableModel;
    ParamValueDelegate *paramValueDelegate;
    RandomModeDelegate *randomModeDelegate;

    //Object to save settings of the session
    VpgSettings& vpgSettings;
};

#endif //MAINDIALOG_H
